==> moodle-1.5-mysql.tgz: moodle/lang/fi/journal.php <==
<?PHP // $Id$ 
      // journal.php - created with Moodle 1.5 + (2005060201)


$string['alwaysopen'] = 'Aina avoinna';
$string['blankentry'] = 'Tyhj osa';
$string['daysavailable'] = 'Piv avoinna';
$string['editingended'] = 'Muokkausaika on loppunut';
$string['editingends'] = 'Muokkausaika loppuu';
$string['entries'] = 'Osat';
$string['feedbackupdated'] = 'Palaute pivitetty $a :lle';
$string['journalmail'] = '$a->teacher on antanut sinulle palautetta muistiosta \'$a->journal\'

Voit nhd sen osoitteessa:

$a->url';
$string['journalmailhtml'] = '$a->teacher on antanut sinulle palautetta muistiosta \'<i>$a->journal</i>\'<br /><br />

Voit nhd sen listtyn

<a href=\"$a->url\">muistioosi</a>.';
$string['journalname'] = 'Muistion nimi';
$string['journalquestion'] = 'Muistion kysymys';
$string['journalrating1'] = 'Vlttv';
$string['journalrating2'] = 'Tyydyttv';
$string['journalrating3'] = 'Kiitettv';
$string['mailsubject'] = 'Muistion palaute';
$string['modulename'] = 'Muistio';
$string['modulenameplural'] = 'Muistiot';
$string['newjournalentries'] = 'Uudet muistiot';
$string['noentry'] = 'Ei palautettu';
$string['noratinggiven'] = 'Ei arvioitu';
$string['notopenuntil'] = 'Tm muistio on tytettviss vasta';
$string['notstarted'] = 'Et ole aloittanut tt muistiota viel';
$string['overallrating'] = 'Yleinen arviointi';
$string['rate'] = 'Arviointi';
$string['saveallfeedback'] = 'Tallenna kaikki palaute';
$string['startoredit'] = 'Aloita tai muokkaa muistiota';
$string['viewallentries'] = 'Katso kaikkia $a muistioita';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/fi/journal.php <==
<?PHP // $Id$ 
      // journal.php - created with Moodle 1.5.2 + (2005060222)


$string['alwaysopen'] = 'Aina avoinna';
$string['blankentry'] = 'Tyhj osa';
$string['daysavailable'] = 'Piv avoinna';
$string['editingended'] = 'Muokkausaika on loppunut';
$string['editingends'] = 'Muokkausaika loppuu';
$string['entries'] = 'Osat';
$string['feedbackupdated'] = 'Palaute pivitetty $a :lle';
$string['journalmail'] = '$a->teacher on antanut sinulle palautetta muistiosta \'$a->journal\'

Voit nhd sen osoitteessa:

$a->url';
$string['journalmailhtml'] = '$a->teacher on antanut sinulle palautetta muistiosta \'<i>$a->journal</i>\'<br /><br />

Voit nhd sen listtyn
<a href=\"$a->url\">muistioosi</a>.';
$string['journalname'] = 'Muistion nimi';
$string['journalquestion'] = 'Muistion kysymys';
$string['journalrating1'] = 'Vlttv';
$string['journalrating2'] = 'Tyydyttv';
$string['journalrating3'] = 'Kiitettv';
$string['mailsubject'] = 'palautetta muistiosta';
$string['modulename'] = 'Muistio';
$string['modulenameplural'] = 'Muistiot';
$string['newjournalentries'] = 'Uudet muistiot';
$string['noentry'] = 'Ei palautettu';
$string['noratinggiven'] = 'Ei arvioitu';
$string['notopenuntil'] = 'Tm muistio on tytettviss vasta';
$string['notstarted'] = 'Et ole aloittanut tt muistiota viel';
$string['overallrating'] = 'Yleinen arviointi';
$string['rate'] = 'Arviointi';
$string['saveallfeedback'] = 'Tallenna kaikki palaute';
$string['startoredit'] = 'Aloita tai muokkaa muistiota';
$string['viewallentries'] = 'Katso kaikkia $a muistioita';

?>
